==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ALabelName.h <==
// public final class soot.jimple.parser.node.ALabelName

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e97cc5e6e606920e soot_jimple_parser_node_ALabelName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class a2102be24ccd06a0 soot_jimple_parser_node_PLabelName

// header file dependencies
// @dep_header soot_jimple_parser_node_PLabelName

#include "soot/jimple/parser/node/PLabelName.h"

#ifndef _JC_soot_jimple_parser_node_ALabelName_H_
#define _JC_soot_jimple_parser_node_ALabelName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TIdentifier$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ALabelName$sub_refs	_jc_soot_jimple_parser_node_ALabelName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ALabelName$sub_nonrefs	_jc_soot_jimple_parser_node_ALabelName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALabelName$refs	_jc_soot_jimple_parser_node_ALabelName$refs;
typedef struct _jc_soot_jimple_parser_node_ALabelName$nonrefs	_jc_soot_jimple_parser_node_ALabelName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALabelName$object	_jc_soot_jimple_parser_node_ALabelName$object;

typedef const struct _jc_soot_jimple_parser_node_ALabelName$vmethods	_jc_soot_jimple_parser_node_ALabelName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ALabelName$vtable	_jc_soot_jimple_parser_node_ALabelName$vtable;
typedef const struct _jc_soot_jimple_parser_node_ALabelName$vtype	_jc_soot_jimple_parser_node_ALabelName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ALabelName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *);
extern void _jc_soot_jimple_parser_node_ALabelName$method$_init$1ad09019f97846a0(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *, struct _jc_soot_jimple_parser_node_TIdentifier$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ALabelName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ALabelName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *);
extern struct _jc_soot_jimple_parser_node_TIdentifier$object *_jc_soot_jimple_parser_node_ALabelName$method$getIdentifier$0f5ff549a337596f(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *);
extern void _jc_soot_jimple_parser_node_ALabelName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ALabelName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ALabelName$method$setIdentifier$2a6f9c69a5ef4095(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *, struct _jc_soot_jimple_parser_node_TIdentifier$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ALabelName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ALabelName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ALabelName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ALabelName$method_info$getIdentifier$0f5ff549a337596f;
extern _jc_method _jc_soot_jimple_parser_node_ALabelName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ALabelName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ALabelName$method_info$setIdentifier$2a6f9c69a5ef4095;
extern _jc_method _jc_soot_jimple_parser_node_ALabelName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ALabelName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *);
	struct _jc_soot_jimple_parser_node_TIdentifier$object	*(*getIdentifier$0f5ff549a337596f)(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setIdentifier$2a6f9c69a5ef4095)(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *, struct _jc_soot_jimple_parser_node_TIdentifier$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ALabelName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PLabelName$vmethods	soot_jimple_parser_node_PLabelName;
	_jc_soot_jimple_parser_node_ALabelName$vmethods	soot_jimple_parser_node_ALabelName;
};

// Vtype
struct _jc_soot_jimple_parser_node_ALabelName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ALabelName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALabelName$sub_refs {
	struct _jc_soot_jimple_parser_node_TIdentifier$object	*__5fidentifier__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALabelName$refs {
    _jc_soot_jimple_parser_node_ALabelName$sub_refs	soot_jimple_parser_node_ALabelName;
    _jc_soot_jimple_parser_node_PLabelName$sub_refs	soot_jimple_parser_node_PLabelName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALabelName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALabelName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PLabelName$sub_nonrefs	soot_jimple_parser_node_PLabelName;
    _jc_soot_jimple_parser_node_ALabelName$sub_nonrefs	soot_jimple_parser_node_ALabelName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ALabelName$object {
	_jc_soot_jimple_parser_node_ALabelName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ALabelName$vtype	*vtype;
	_jc_soot_jimple_parser_node_ALabelName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ALabelName$vtype _jc_soot_jimple_parser_node_ALabelName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ALabelName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ALabelName$class_object;

#endif	/* _JC_soot_jimple_parser_node_ALabelName_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ALabelName.h <==
// public final class soot.jimple.parser.node.ALabelName

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e97cc5e6e606920e soot_jimple_parser_node_ALabelName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class a2102be24ccd06a0 soot_jimple_parser_node_PLabelName

// header file dependencies
// @dep_header soot_jimple_parser_node_PLabelName

#include "soot/jimple/parser/node/PLabelName.h"

#ifndef _JC_soot_jimple_parser_node_ALabelName_H_
#define _JC_soot_jimple_parser_node_ALabelName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TIdentifier$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ALabelName$sub_refs	_jc_soot_jimple_parser_node_ALabelName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ALabelName$sub_nonrefs	_jc_soot_jimple_parser_node_ALabelName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALabelName$refs	_jc_soot_jimple_parser_node_ALabelName$refs;
typedef struct _jc_soot_jimple_parser_node_ALabelName$nonrefs	_jc_soot_jimple_parser_node_ALabelName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALabelName$object	_jc_soot_jimple_parser_node_ALabelName$object;

typedef const struct _jc_soot_jimple_parser_node_ALabelName$vmethods	_jc_soot_jimple_parser_node_ALabelName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ALabelName$vtable	_jc_soot_jimple_parser_node_ALabelName$vtable;
typedef const struct _jc_soot_jimple_parser_node_ALabelName$vtype	_jc_soot_jimple_parser_node_ALabelName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ALabelName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALabelName$method$_init$1ad09019f97846a0(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *, struct _jc_soot_jimple_parser_node_TIdentifier$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ALabelName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ALabelName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TIdentifier$object *_jc_soot_jimple_parser_node_ALabelName$method$getIdentifier$0f5ff549a337596f(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALabelName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALabelName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALabelName$method$setIdentifier$2a6f9c69a5ef4095(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *, struct _jc_soot_jimple_parser_node_TIdentifier$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ALabelName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ALabelName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ALabelName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ALabelName$method_info$getIdentifier$0f5ff549a337596f;
extern _jc_method _jc_soot_jimple_parser_node_ALabelName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ALabelName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ALabelName$method_info$setIdentifier$2a6f9c69a5ef4095;
extern _jc_method _jc_soot_jimple_parser_node_ALabelName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ALabelName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TIdentifier$object	*(*getIdentifier$0f5ff549a337596f)(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setIdentifier$2a6f9c69a5ef4095)(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *, struct _jc_soot_jimple_parser_node_TIdentifier$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ALabelName$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ALabelName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PLabelName$vmethods	soot_jimple_parser_node_PLabelName;
	_jc_soot_jimple_parser_node_ALabelName$vmethods	soot_jimple_parser_node_ALabelName;
};

// Vtype
struct _jc_soot_jimple_parser_node_ALabelName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ALabelName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALabelName$sub_refs {
	struct _jc_soot_jimple_parser_node_TIdentifier$object	*__5fidentifier__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALabelName$refs {
    _jc_soot_jimple_parser_node_ALabelName$sub_refs	soot_jimple_parser_node_ALabelName;
    _jc_soot_jimple_parser_node_PLabelName$sub_refs	soot_jimple_parser_node_PLabelName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALabelName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALabelName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PLabelName$sub_nonrefs	soot_jimple_parser_node_PLabelName;
    _jc_soot_jimple_parser_node_ALabelName$sub_nonrefs	soot_jimple_parser_node_ALabelName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ALabelName$object {
	_jc_soot_jimple_parser_node_ALabelName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ALabelName$vtype	*vtype;
	_jc_soot_jimple_parser_node_ALabelName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ALabelName$vtype _jc_soot_jimple_parser_node_ALabelName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ALabelName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ALabelName$class_object;

#endif	/* _JC_soot_jimple_parser_node_ALabelName_H_ */
